==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QBufferCapture.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Exchanges buffer data between GPU and CPU</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qbuffercapture.html">Qt3DRender::QBufferCapture</a></code></p>
 */
public class QBufferCapture extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QBufferCapture.class);
    
    
    /**
     * <p>See <code>Qt3DRender::QBufferCapture::<wbr>QBufferCapture(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QBufferCapture(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QBufferCapture instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QBufferCapture(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QBufferCapture(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QBufferCapture instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QBufferCapture(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QBufferCapture() {
        this((io.qt.qt3d.core.QNode)null);
    }
}

==> qtjambi-qt3drender-6.6.1-sources.jar: io/qt/qt3d/render/QBufferCapture.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Exchanges buffer data between GPU and CPU</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qbuffercapture.html">Qt3DRender::QBufferCapture</a></code></p>
 */
public class QBufferCapture extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QBufferCapture.class);
    
    
    /**
     * <p>See <code>Qt3DRender::QBufferCapture::<wbr/>QBufferCapture(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QBufferCapture(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QBufferCapture instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QBufferCapture(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QBufferCapture(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QBufferCapture instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QBufferCapture(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QBufferCapture() {
        this((io.qt.qt3d.core.QNode)null);
    }
}
